//
//  MultiFriendEmbededViewController.swift
//  KakaoPartnerSDKSample
//
//  Created by kakao on 2/11/25.
//  Copyright © 2025 apiteam. All rights reserved.
//

import UIKit

import KakaoSDKCommon
import KakaoSDKAuth
import KakaoSDKTalk
import KakaoPartnerSDKTalk
import KakaoPartnerSDKFriendDelegate

class MultiFriendEmbededViewController: BaseEmbededViewController {
    private let okBtn: UIButton = {
        let button = UIButton()
        button.setTitle("OK", for: .normal)
        button.setTitleColor(.black, for: .normal)
        button.addTarget(self, action: #selector(getSelectedUsers), for: .touchUpInside)
        
        return button
    }()
    
    private func setOkButtonLayout() {
        naviView.addSubview(okBtn)
        
        okBtn.translatesAutoresizingMaskIntoConstraints = false
        okBtn.topAnchor.constraint(equalTo: naviView.topAnchor).isActive = true
        okBtn.trailingAnchor.constraint(equalTo: naviView.trailingAnchor, constant: -10).isActive = true
        okBtn.bottomAnchor.constraint(equalTo: naviView.bottomAnchor).isActive = true
    }
    
    override func viewDidLoad() {
        setOkButtonLayout()
        getPickerView()
    }
    
    func getPickerView() {
        TalkApi.shared.friendsForPartner(context: PartnerFriendsContext()) { [weak self] friends, error in
            if let error {
                self?.showAlert(value: error)
                return
            }
            
            if let friends, let firstUser = friends.elements?.first {
                self?.getPickerViewWithCustomSection(user: firstUser)
            }
        }
    }
    
    private func getPickerViewWithCustomSection(user: PartnerFriend) {
        guard let appKey = try? KakaoSDK.shared.appKey(),
              let bundleId = Bundle.main.bundleIdentifier,
              let accessToken = TokenManager.manager.getToken()?.accessToken else {
            dismiss(animated: true)
            
            return
        }
                
        let params = PickerFriendRequestParams(showFavorite: false)
        let targetInfo = TargetInfo(appKey: appKey, bundleId: bundleId, accessToken: accessToken)
        
        PickerApi.shared.multiFriendPickerView(
            params: params,
            targetInfo: targetInfo,
            selectedUuids: [user.uuid],
            customSection: CustomSection(title: "Custom Section in Multi", uuids: [user.uuid])
        ) { [weak self] resultView, error in
            if let error {
                print("##### error occur: \(error)")

                DispatchQueue.main.async {
                    self?.dismiss(animated: true)
                }
            }

            if let resultView {
                self?.pickerView = resultView
                self?.setLayout()
            }
        }
    }
    
    override func viewWillTransition(to size: CGSize, with coordinator: any UIViewControllerTransitionCoordinator) {
        coordinator.animate { [weak self] _ in
            self?.pickerView?.updateSubviewsConstraint()
        }
        super.viewWillTransition(to: size, with: coordinator)
    }
}
